@@ -1,9 +1,9 @@
 <?php
 
-class Managesieve_Plugin extends PHPUnit_Framework_TestCase
+class Managesieve_Plugin extends PHPUnit\Framework\TestCase
 {
 
-    function setUp()
+    static function setUpBeforeClass(): void
     {
         include_once __DIR__ . '/../managesieve.php';
     }
@@ -20,4 +20,3 @@ class Managesieve_Plugin extends PHPUnit_Framework_TestCase
         $this->assertInstanceOf('rcube_plugin', $plugin);
     }
 }
-
