@@ -2,8 +2,7 @@
 
 class VirtuserQuery_Plugin extends PHPUnit\Framework\TestCase
 {
-
-    function setUp()
+    public static function setUpBeforeClass(): void
     {
         include_once __DIR__ . '/../virtuser_query.php';
     }
