@@ -37,7 +37,7 @@ class Browser extends \Laravel\Dusk\Browser
      */
     public function assertEnvEquals($key, $expected)
     {
-        $this->assertEquals($expected, $this->getEnv($key));
+        Assert::assertEquals($expected, $this->getEnv($key));
 
         return $this;
     }
@@ -143,6 +143,14 @@ class Browser extends \Laravel\Dusk\Browser
         return $this;
     }
 
+    /**
+     * Return rcmail.env entry
+     */
+    public function getEnv($key)
+    {
+        return $this->driver->executeScript("return rcmail.env['{$key}']");
+    }
+
     /**
      * Visit specified task/action with logon if needed
      */
