@@ -340,7 +340,7 @@ class Framework_Mime extends PHPUnit\Framework\TestCase
         $this->assertSame(257,              $result->parts[1]->parts[0]->size);
         $this->assertSame('text/html',      $result->parts[1]->parts[0]->mimetype);
         $this->assertSame('UTF-8',          $result->parts[1]->parts[0]->charset);
-        $this->assertRegExp('/<html>/',     $result->parts[1]->parts[0]->body);
+        $this->assertMatchesRegularExpression('/<html>/', $result->parts[1]->parts[0]->body);
         $this->assertSame('2.2',            $result->parts[1]->parts[1]->mime_id);
         $this->assertSame(793,              $result->parts[1]->parts[1]->size);
         $this->assertSame('image/jpeg',     $result->parts[1]->parts[1]->mimetype);
