@@ -291,9 +291,9 @@ class Framework_Utils extends PHPUnit\Framework\TestCase
         $mod = rcube_utils::mod_css_styles($style, 'rcmbody', true);
         $this->assertSame("#rcmbody { content: ''; color: red; }", $mod);
 
-        $style = "body { content: '< page: ;/style>< page: ;img src onerror=\"alert(\'hello\');\">'; color: red; }";
+        $style = "body { content: '< page: ;/style>< page: ;img src onerror=\"alert(\\'hello\\');\">'; color: red; }";
         $mod = rcube_utils::mod_css_styles($style, 'rcmbody', true);
-        $this->assertSame("#rcmbody { content: '< page: ;/style>< page: ;img src onerror=\"alert('hello');\">'; color: red; }", $mod);
+        $this->assertSame("#rcmbody { color: red; }", $mod);
 
         // Removing page: property
         $style = "body { page: test; color: red }";
@@ -423,6 +423,10 @@ class Framework_Utils extends PHPUnit\Framework\TestCase
                 'font-family:"新細明體","serif";color:red',
                 [['font-family', '"新細明體","serif"'], ['color', 'red']]
             ],
+            [
+                'text-align: center; ;      background-color: #C83232; color: #ffffff; ;  display: inline-block;',
+                [['text-align', 'center'], ['background-color', '#C83232'], ['color', '#ffffff'], ['display', 'inline-block']],
+            ],
         ];
     }
 
@@ -431,7 +435,7 @@ class Framework_Utils extends PHPUnit\Framework\TestCase
      *
      * @dataProvider data_parse_css_block
      */
-    function test_explode_style($input, $output)
+    function test_parse_css_block($input, $output)
     {
         $this->assertSame($output, rcube_utils::parse_css_block($input));
     }
